require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_adcscertificationauthoritysettings',
  dscmeta_resource_friendly_name: 'AdcsCertificationAuthoritySettings',
  dscmeta_resource_name: 'DSC_AdcsCertificationAuthoritySettings',
  dscmeta_module_name: 'ActiveDirectoryCSDsc',
  dscmeta_module_version: '5.0.0',
  docs: 'The DSC AdcsCertificationAuthoritySettings resource type.
         Automatically generated from version 5.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_crlpublicationurls: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of Certificate Revocation List publication URLs, each prepended with an integer representing the type of URL endpoint.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_dsdomaindn: {
      type: 'Optional[String]',
      desc: 'Specifies the distinguished name of the directory services object that contains this certificate authority in the Active Directory.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_crloverlapunits: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the number of units for the certificate revocation list overlap period.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_validityperiodunits: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the number of units for the validity period of certificates issued by this certificate authority.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_cacertpublicationurls: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of Certificate Authority certificate publication URLs, each prepended with an integer representing the type of URL endpoint.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_dsconfigdn: {
      type: 'Optional[String]',
      desc: 'Specifies the distinguished name of the directory services configuration object that contains this certificate authority in the Active Directory.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_crlperiod: {
      type: "Optional[Enum['Hours', 'Days', 'Weeks', 'Months', 'Years']]",
      desc: 'Specifies the units of measurement for the certificate revocation period.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_validityperiod: {
      type: "Optional[Enum['Hours', 'Days', 'Weeks', 'Months', 'Years']]",
      desc: 'Specifies the units of measurement for the validity period of certificates issued by this certificate authority.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_auditfilter: {
      type: "Optional[Array[Enum['StartAndStopADCS', 'BackupAndRestoreCADatabase', 'IssueAndManageCertificateRequests', 'RevokeCertificatesAndPublishCRLs', 'ChangeCASecuritySettings', 'StoreAndRetrieveArchivedKeys', 'ChangeCAConfiguration']]]",
      desc: 'Specifies an array of audit categories to enable audit logging for.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_issingleinstance: {
      type: "Enum['Yes']",
      desc: "Specifies the resource is a single instance, the value must be 'Yes'.",
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_crlperiodunits: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the number of units for the certificate revocation period.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_crloverlapperiod: {
      type: "Optional[Enum['Hours', 'Days', 'Weeks', 'Months', 'Years']]",
      desc: 'Specifies the units of measurement for the certificate revocation list overlap period.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
