require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_adcsenrollmentpolicywebservice',
  dscmeta_resource_friendly_name: 'AdcsEnrollmentPolicyWebService',
  dscmeta_resource_name: 'DSC_AdcsEnrollmentPolicyWebService',
  dscmeta_module_name: 'ActiveDirectoryCSDsc',
  dscmeta_module_version: '5.0.0',
  docs: 'The DSC AdcsEnrollmentPolicyWebService resource type.
         Automatically generated from version 5.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'If the Certificate Enrollment Policy Web service is configured to use Standalone certification authority, then an account that is a member of the local Administrators on the CA is required. If the Certificate Enrollment Policy Web service is configured to use an Enterprise CA, then an account that is a member of Domain Admins is required.',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Specifies whether the Certificate Enrollment Policy Web feature should be installed or uninstalled. Defaults to Present.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sslcertthumbprint: {
      type: 'String',
      desc: 'Specifies the thumbprint of the certificate used by Internet Information Service (IIS) to enable support for required Secure Sockets Layer (SSL).',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_authenticationtype: {
      type: "Enum['Certificate', 'Kerberos', 'UserName']",
      desc: 'Specifies the authentication type used by the Certificate Enrollment Policy Web Service.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_keybasedrenewal: {
      type: 'Optional[Boolean]',
      desc: 'Configures the Certificate Enrollment Policy Web Service to operate in key-based renewal mode. Defaults to False.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
